pub struct ExtDataControlStream { /* private fields */ }Expand description
The main object to send and receive events over ext-data-control Wayland protocol
Implementations
Sourceimpl ExtDataControlStream
impl ExtDataControlStream
Sourcepub fn new() -> Result<Self, ExtDataControlConnectError>
pub fn new() -> Result<Self, ExtDataControlConnectError>
Sourcepub fn offer_text(
&mut self,
text: impl Into<String>,
) -> Result<(), WaylandError>
pub fn offer_text( &mut self, text: impl Into<String>, ) -> Result<(), WaylandError>
Push a text, so that other Wayland clients (i.e. apps) can “paste” it
Errors
Returns an error if any internal component has errored.
Sourcepub fn drain(
&mut self,
) -> Result<Vec<ExtDataControlEvent>, ExtDataControlReadError>
pub fn drain( &mut self, ) -> Result<Vec<ExtDataControlEvent>, ExtDataControlReadError>
Drains all immediately available events from underlying resources and returns them, assuming that there’s something to read.
This method should be called if you know that the stream is readable
(i.e. by calling select/poll/epoll first on a file descriptor of ExtDataControlStream object)
Errors
Returns an error if any of underlying components errored.